@@ -1,7 +1,8 @@
 /*
-  Xnee's Not an Event Emulator enables recording and replaying of X protocol data
+  Xnee's Not an Event Emulator enables recording and replaying of X 
+  protocol data
   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 
-                2007 Henrik Sandklef
+                2007, 2008 Henrik Sandklef
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -33,6 +34,10 @@
 #include "libxnee/xnee_session.h"
 
 
+#define XNEE_HP_SEP " "
+#define XNEE_HP_EQUALS "="
+#define XNEE_HP_CONTENT_BEGIN " { "
+#define XNEE_HP_CONTENT_END " } "
 
 
 /*
@@ -213,17 +218,96 @@ xnee_record_print_request (xnee_data *xd, XRecordInterceptData *xrecintd )
  */
 void 
 xnee_human_print_request (xnee_data *xd, XRecordInterceptData *xrecintd )
+{
+  XRecordDatum *xrec_data;
+  int           request_type ;
+  char  *request_name ;
+  char  *name=" not defined " ;
+  xrec_data  = (XRecordDatum *) (xrecintd->data) ;
+
+  request_type = (int)xrec_data->type ;
+  request_name = " not defined " ;
+
+  request_name = xnee_print_request(request_type);
+    if ( request_name == NULL )
+      {
+	request_name = name;
+      }
+
+  (void)xd->data_fp (xd->out_file,"Request" XNEE_HP_EQUALS "%s" XNEE_HP_SEP "Number" XNEE_HP_EQUALS "%d", 
+		     request_name, request_type);
+  
+  if ( 1 )
+    {
+      (void)xd->data_fp (xd->out_file,XNEE_HP_CONTENT_BEGIN); 
+      xnee_human_print_request_verbose (xd,xrecintd );
+      (void)xd->data_fp (xd->out_file,XNEE_HP_CONTENT_END); 
+    }
+
+  (void)xd->data_fp (xd->out_file,"\n");
+}
+
+
+/*
+ *
+ * xnee_human_print_request.  
+ *
+ */
+void 
+xnee_human_print_request_verbose (xnee_data *xd, XRecordInterceptData *xrecintd )
 {
   XRecordDatum *xrec_data;
   int           req_type ;
+  xCreateWindowReq *req_create_ptr;
 
   xrec_data = (XRecordDatum *) (xrecintd->data) ;
   req_type  = (int) xrec_data->type ;
   
-  (void)xd->data_fp (xd->out_file,"Request   %20s\t%.3d\t%lu\n", 
-		     xnee_print_request(req_type),
-		     req_type,
-		     xrec_data->req.id    );
+  switch (req_type)
+    {
+    case X_CreateWindow:
+      req_create_ptr = (xCreateWindowReq *) (xrecintd->data) ;
+      (void)xd->data_fp (xd->out_file,
+			 XNEE_HP_SEP "reqType" XNEE_HP_EQUALS "%c"
+			 XNEE_HP_SEP "depth"   XNEE_HP_EQUALS "%d"
+			 XNEE_HP_SEP "length"  XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "wid"     XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "parent"  XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "width"   XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "height"  XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "borderWidth" XNEE_HP_EQUALS "%lu"
+#if defined(__cplusplus) || defined(c_plusplus)
+			 XNEE_HP_SEP "c_class" XNEE_HP_EQUALS "%lu"
+#else
+			 XNEE_HP_SEP "class"   XNEE_HP_EQUALS "%lu"
+#endif
+			 XNEE_HP_SEP "visual"  XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "mask"    XNEE_HP_EQUALS "%lu",
+			 req_create_ptr->reqType, 
+			 req_create_ptr->depth, 
+			 req_create_ptr->length, 
+			 req_create_ptr->wid, 
+			 req_create_ptr->parent, 
+			 req_create_ptr->width, 
+			 req_create_ptr->height, 
+			 req_create_ptr->borderWidth, 
+#if defined(__cplusplus) || defined(c_plusplus)
+			 req_create_ptr->c_class, 
+#else
+			 req_create_ptr->class, 
+#endif
+			 req_create_ptr->visual, 
+			 req_create_ptr->mask);
+     break;
+    case sz_xReparentWindowReq:
+      (void)xd->data_fp (xd->out_file,
+			 XNEE_HP_SEP "length" XNEE_HP_EQUALS "%lu  RE ",
+			 xrec_data->req.length);
+     break;
+    default:
+      (void)xd->data_fp (xd->out_file, " NOT IMPLEMENTED REQUEST ");
+      break;
+    }
 }
 
 /*
@@ -236,23 +320,412 @@ xnee_human_print_event (xnee_data *xd, XRecordInterceptData *xrecintd )
 {
   XRecordDatum *xrec_data  ;
   int           event_type ;
+  
+
+  char  *event_name ;
+  char  *name=" not defined " ;
+  xrec_data  = (XRecordDatum *) (xrecintd->data) ;
+  event_type = (int)xrec_data->type ;
+  event_name = " not defined " ;
+
+  event_name = xnee_print_event(event_type);
+    if ( event_name == NULL )
+      {
+	event_name = name;
+      }
+
+  (void)xd->data_fp (xd->out_file,"Event" XNEE_HP_EQUALS "%s" XNEE_HP_SEP "Number" XNEE_HP_EQUALS "%d", 
+		     event_name, event_type);
+  
+  if ( 1 )
+    {
+      (void)xd->data_fp (xd->out_file,XNEE_HP_CONTENT_BEGIN); 
+      xnee_human_print_event_verbose (xd,xrecintd );
+      (void)xd->data_fp (xd->out_file,XNEE_HP_CONTENT_END); 
+    }
+
+  (void)xd->data_fp (xd->out_file,"\n");
+}
+
+
+/*
+ *
+ * xnee_human_print_event.  
+ *
+ */
+void 
+xnee_human_print_event_verbose (xnee_data *xd, XRecordInterceptData *xrecintd )
+{
+  XRecordDatum *xrec_data  ;
+  int           event_type ;
+  int i ;
 
   xrec_data  = (XRecordDatum *) (xrecintd->data) ;
   event_type = (int)xrec_data->type ;
 
+
+  (void)xd->data_fp (xd->out_file, "{ ");
   switch (event_type)
     {
-    case CreateNotify:
-      (void)xd->data_fp (xd->out_file,"Event     %20s\t%.3d\t%lu\n", 
-			 xnee_print_event(event_type), 
-			 event_type,
-			 xrec_data->event.u.createNotify.window);
+    case KeyPress:
+    case KeyRelease:
+    case ButtonPress:
+    case ButtonRelease:
+    case MotionNotify:
+      (void)xd->data_fp (xd->out_file,
+			  "root" XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "event" XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "child" XNEE_HP_EQUALS "%lu", 
+			 xrec_data->event.u.keyButtonPointer.root,
+			 xrec_data->event.u.keyButtonPointer.event,
+			 xrec_data->event.u.keyButtonPointer.child
+			 );
+      (void)xd->data_fp (xd->out_file,
+			 XNEE_HP_SEP "rootX" XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "rootY" XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "eventX" XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "eventY" XNEE_HP_EQUALS "%lu", 
+			 xrec_data->event.u.keyButtonPointer.rootX,
+			 xrec_data->event.u.keyButtonPointer.rootY,
+			 xrec_data->event.u.keyButtonPointer.eventX,
+			 xrec_data->event.u.keyButtonPointer.eventY
+			 );
+      (void)xd->data_fp (xd->out_file,
+			 XNEE_HP_SEP "state" XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "sameScreen" XNEE_HP_EQUALS "%d", 
+			 xrec_data->event.u.keyButtonPointer.state,
+			 xrec_data->event.u.keyButtonPointer.sameScreen			 );
       break;
+    case EnterNotify:
+    case LeaveNotify:
+      (void)xd->data_fp (xd->out_file,
+			  "root" XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "event" XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "child" XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "rootX" XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "rootY" XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "eventX" XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "eventY" XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "state" XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "mode" XNEE_HP_EQUALS "%d", 
+			 xrec_data->event.u.enterLeave.root,
+			 xrec_data->event.u.enterLeave.event,
+			 xrec_data->event.u.enterLeave.child,
+			 xrec_data->event.u.enterLeave.rootX,
+			 xrec_data->event.u.enterLeave.rootY,
+			 xrec_data->event.u.enterLeave.eventX,
+			 xrec_data->event.u.enterLeave.eventY,
+			 xrec_data->event.u.enterLeave.state,
+			 xrec_data->event.u.enterLeave.mode);
+      break;
+
+    case FocusIn:
+    case FocusOut:
+      (void)xd->data_fp (xd->out_file,
+			  "window" XNEE_HP_EQUALS "%lu"
+			 XNEE_HP_SEP "mode" XNEE_HP_EQUALS "%lu", 
+			 xrec_data->event.u.focus.window,
+			 xrec_data->event.u.focus.mode);
+      break;
+    case Expose:
+      (void)xd->data_fp (xd->out_file,
+			  "window" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "x" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "y" XNEE_HP_EQUALS "%d"  
+			 XNEE_HP_SEP "width" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "height" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "count" XNEE_HP_EQUALS "%d", 
+			 xrec_data->event.u.expose.window,
+			 xrec_data->event.u.expose.x,
+			 xrec_data->event.u.expose.y,
+			 xrec_data->event.u.expose.width,
+			 xrec_data->event.u.expose.height,
+			 xrec_data->event.u.expose.count);
+      break;
+    case GraphicsExpose:
+      (void)xd->data_fp (xd->out_file,
+			  "drawable" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "x" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "y" XNEE_HP_EQUALS "%d"  
+			 XNEE_HP_SEP "width" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "height" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "minorEvent" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "majorEvent" XNEE_HP_EQUALS "%d"
+			 XNEE_HP_SEP "count" XNEE_HP_EQUALS "%d", 
+			 xrec_data->event.u.graphicsExposure.drawable,
+			 xrec_data->event.u.graphicsExposure.x,
+			 xrec_data->event.u.graphicsExposure.y,
+			 xrec_data->event.u.graphicsExposure.width,
+			 xrec_data->event.u.graphicsExposure.height,
+			 xrec_data->event.u.graphicsExposure.minorEvent,
+			 xrec_data->event.u.graphicsExposure.majorEvent,
+			 xrec_data->event.u.graphicsExposure.count);
+      break;
+    case NoExpose:
+      (void)xd->data_fp (xd->out_file,
+			  "drawable" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "minorEvent" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "majorEvent" XNEE_HP_EQUALS "%d" , 
+			 xrec_data->event.u.noExposure.drawable,
+			 xrec_data->event.u.noExposure.minorEvent,
+			 xrec_data->event.u.noExposure.majorEvent);
+      break;
+    case VisibilityNotify:
+      (void)xd->data_fp (xd->out_file,
+			  "window" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "state" XNEE_HP_EQUALS "%d" , 
+			 xrec_data->event.u.visibility.window,
+			 xrec_data->event.u.visibility.state);
+      break;
+    case CreateNotify:
+      (void)xd->data_fp (xd->out_file,
+			  "parent" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "window" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "x" XNEE_HP_EQUALS "%d"  
+			 XNEE_HP_SEP "y" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "width" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "height" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "borderWidth" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "override" XNEE_HP_EQUALS "%d" ,
+			 xrec_data->event.u.createNotify.parent,
+			 xrec_data->event.u.createNotify.window,
+			 xrec_data->event.u.createNotify.x,
+			 xrec_data->event.u.createNotify.y,
+			 xrec_data->event.u.createNotify.width,
+			 xrec_data->event.u.createNotify.height,
+			 xrec_data->event.u.createNotify.borderWidth,
+			 xrec_data->event.u.createNotify.override);
+      break;
+    case DestroyNotify:
+      (void)xd->data_fp (xd->out_file,
+			  "event" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "window" XNEE_HP_EQUALS "%lu" ,
+			 xrec_data->event.u.destroyNotify.event,
+			 xrec_data->event.u.destroyNotify.window);
+      break;
+    case UnmapNotify:
+      (void)xd->data_fp (xd->out_file,
+			  "event" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "window" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "fromConfigure" XNEE_HP_EQUALS "%d" ,
+			 xrec_data->event.u.unmapNotify.event,
+			 xrec_data->event.u.unmapNotify.window,
+			 xrec_data->event.u.unmapNotify.fromConfigure);
+      break;
+    case MapNotify:
+      (void)xd->data_fp (xd->out_file,
+			  "event" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "window" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "override" XNEE_HP_EQUALS "%d" ,
+			 xrec_data->event.u.mapNotify.event,
+			 xrec_data->event.u.mapNotify.window,
+			 xrec_data->event.u.mapNotify.override);
+      break;
+    case MapRequest:
+      (void)xd->data_fp (xd->out_file,
+			  "parent" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "window" XNEE_HP_EQUALS "%lu",
+			 xrec_data->event.u.mapRequest.parent,
+			 xrec_data->event.u.mapRequest.window);
+      break;
+    case ReparentNotify:
+      (void)xd->data_fp (xd->out_file,
+			  "event" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "window" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "parent" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "x" XNEE_HP_EQUALS "%d"  
+			 XNEE_HP_SEP "y" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "override" XNEE_HP_EQUALS "%d" ,
+			 xrec_data->event.u.reparent.event,
+			 xrec_data->event.u.reparent.window,
+			 xrec_data->event.u.reparent.parent,
+			 xrec_data->event.u.reparent.x,
+			 xrec_data->event.u.reparent.y,
+			 xrec_data->event.u.reparent.override);
+      break;
+    case ConfigureNotify:
+      (void)xd->data_fp (xd->out_file,
+			  "event" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "window" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "aboveSibling" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "parent" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "x" XNEE_HP_EQUALS "%d"  
+			 XNEE_HP_SEP "y" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "width" XNEE_HP_EQUALS "%d"  
+			 XNEE_HP_SEP "height" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "borderWidth" XNEE_HP_EQUALS "%d"  
+			 XNEE_HP_SEP "override" XNEE_HP_EQUALS "%d" ,
+			 xrec_data->event.u.configureNotify.event,
+			 xrec_data->event.u.configureNotify.window,
+			 xrec_data->event.u.configureNotify.aboveSibling,
+			 xrec_data->event.u.configureNotify.x,
+			 xrec_data->event.u.configureNotify.y,
+			 xrec_data->event.u.configureNotify.width,
+			 xrec_data->event.u.configureNotify.height,
+			 xrec_data->event.u.configureNotify.borderWidth,
+			 xrec_data->event.u.configureNotify.override);
+      break;
+    case ConfigureRequest:
+      (void)xd->data_fp (xd->out_file,
+			  "parent" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "window" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "sibling" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "x" XNEE_HP_EQUALS "%d"  
+			 XNEE_HP_SEP "y" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "width" XNEE_HP_EQUALS "%d"  
+			 XNEE_HP_SEP "height" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "borderWidth" XNEE_HP_EQUALS "%d"  
+			 XNEE_HP_SEP "valueMask" XNEE_HP_EQUALS "%d" ,
+			 xrec_data->event.u.configureRequest.parent,
+			 xrec_data->event.u.configureRequest.window,
+			 xrec_data->event.u.configureRequest.sibling,
+			 xrec_data->event.u.configureRequest.x,
+			 xrec_data->event.u.configureRequest.y,
+			 xrec_data->event.u.configureRequest.width,
+			 xrec_data->event.u.configureRequest.height,
+			 xrec_data->event.u.configureRequest.borderWidth,
+			 xrec_data->event.u.configureRequest.valueMask);
+      break;
+
+    case GravityNotify:
+      (void)xd->data_fp (xd->out_file,
+			 XNEE_HP_SEP "event" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "window" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "x" XNEE_HP_EQUALS "%d"  
+			 XNEE_HP_SEP "y" XNEE_HP_EQUALS "%d" ,
+			 xrec_data->event.u.gravity.event,
+			 xrec_data->event.u.gravity.window,
+			 xrec_data->event.u.gravity.x,
+			 xrec_data->event.u.gravity.y);
+      break;
+
+    case ResizeRequest:
+      (void)xd->data_fp (xd->out_file,
+			 XNEE_HP_SEP "window" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "width" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "height" XNEE_HP_EQUALS "%d" ,
+			 xrec_data->event.u.resizeRequest.window,
+			 xrec_data->event.u.resizeRequest.width,
+			 xrec_data->event.u.resizeRequest.height);
+      break;
+
+    case CirculateNotify:
+    case CirculateRequest:
+      (void)xd->data_fp (xd->out_file,
+			 XNEE_HP_SEP "event" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "window" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "parent" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "place" XNEE_HP_EQUALS "%lu" ,
+			 xrec_data->event.u.circulate.event,
+			 xrec_data->event.u.circulate.window,
+			 xrec_data->event.u.circulate.parent,
+			 xrec_data->event.u.circulate.place);
+      break;
+
+    case PropertyNotify:
+      (void)xd->data_fp (xd->out_file,
+			 XNEE_HP_SEP "window" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "atom" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "time" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "state" XNEE_HP_EQUALS "%d" ,
+			 xrec_data->event.u.property.window,
+			 xrec_data->event.u.property.atom,
+			 xrec_data->event.u.property.time,
+			 xrec_data->event.u.property.state);
+      break;
+
+    case SelectionClear:
+      (void)xd->data_fp (xd->out_file,
+			 XNEE_HP_SEP "time" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "window" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "atom" XNEE_HP_EQUALS "%d" ,
+			 xrec_data->event.u.selectionClear.time,
+			 xrec_data->event.u.selectionClear.window,
+			 xrec_data->event.u.selectionClear.atom);
+      break;
+
+    case SelectionRequest:
+      (void)xd->data_fp (xd->out_file,
+			 XNEE_HP_SEP "time" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "owner" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "requestor" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "selection" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "target" XNEE_HP_EQUALS "%d" ,
+			 XNEE_HP_SEP "property" XNEE_HP_EQUALS "%d" ,
+			 xrec_data->event.u.selectionRequest.time,
+			 xrec_data->event.u.selectionRequest.owner,
+			 xrec_data->event.u.selectionRequest.requestor,
+			 xrec_data->event.u.selectionRequest.selection,
+			 xrec_data->event.u.selectionRequest.target,
+			 xrec_data->event.u.selectionRequest.property);
+      break;
+
+    case SelectionNotify:
+      (void)xd->data_fp (xd->out_file,
+			 XNEE_HP_SEP "time" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "requestor" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "selection" XNEE_HP_EQUALS "%d" 
+			 XNEE_HP_SEP "target" XNEE_HP_EQUALS "%d" ,
+			 XNEE_HP_SEP "property" XNEE_HP_EQUALS "%d" ,
+			 xrec_data->event.u.selectionNotify.time,
+			 xrec_data->event.u.selectionNotify.requestor,
+			 xrec_data->event.u.selectionNotify.selection,
+			 xrec_data->event.u.selectionNotify.target,
+			 xrec_data->event.u.selectionNotify.property);
+      break;
+
+    case ColormapNotify:
+      (void)xd->data_fp (xd->out_file,
+			 XNEE_HP_SEP "window" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "colormap" XNEE_HP_EQUALS "%lu" 
+#if defined(__cplusplus) || defined(c_plusplus)
+			 XNEE_HP_SEP "c_new" XNEE_HP_EQUALS "%d" 
+#else
+			 XNEE_HP_SEP "new" XNEE_HP_EQUALS "%d" 
+#endif
+			 XNEE_HP_SEP "state" XNEE_HP_EQUALS "%d" ,
+			 xrec_data->event.u.colormap.window,
+			 xrec_data->event.u.colormap.colormap,
+#if defined(__cplusplus) || defined(c_plusplus)
+			 xrec_data->event.u.colormap.c_new,
+#else
+			 xrec_data->event.u.colormap.new,
+#endif
+			 xrec_data->event.u.colormap.state);
+      break;
+
+    case ClientMessage:
+      (void)xd->data_fp (xd->out_file,
+			 XNEE_HP_SEP "window" XNEE_HP_EQUALS "%lu" ,
+			 xrec_data->event.u.clientMessage.window );
+      /*
+      (void)xd->data_fp (xd->out_file, "bytes" XNEE_HP_EQUALS " {");
+      for (i=0;i<20;i++)
+	{
+	  (void)xd->data_fp (xd->out_file, "%c ", 
+			     xrec_data->event.u.clientMessage.u.b.bytes[i]);
+
+	}
+      (void)xd->data_fp (xd->out_file, "} ");
+      */
+      break;
+
+    case MappingNotify:
+      (void)xd->data_fp (xd->out_file,
+			 XNEE_HP_SEP "request" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "firstKeyCode" XNEE_HP_EQUALS "%lu" 
+			 XNEE_HP_SEP "count" XNEE_HP_EQUALS "%d" ,
+			 xrec_data->event.u.mappingNotify.request,
+			 xrec_data->event.u.mappingNotify.firstKeyCode,
+			 xrec_data->event.u.mappingNotify.count);
+      break;
+
     default:
-      (void)xd->data_fp (xd->out_file,"Event     %20s\t%.3d\n", 
-			 xnee_print_event(event_type), event_type);
+      (void)xd->data_fp (xd->out_file," NOT IMPLEMENTED ");
       break;
     }
+  (void)xd->data_fp (xd->out_file, " }");
+
 }
 
 
