@@ -236,7 +236,7 @@ static xnee_option_t xnee_options_impl[] =
     
     {
       XNEE_EXEC_PROGRAM_KEY,
-      "exec-key",
+      "exec-program-key",
       "ep",
       "<programname>", 
       "Program to start when pressing the grabbed exec key",
@@ -589,6 +589,15 @@ static xnee_option_t xnee_options_impl[] =
       XNEE_REPLAY_OPTION,
       XNEE_OPTION_VISIBLE
     },
+    {
+      XNEE_KEEP_AUTOREPEAT,
+      "keep-autorepeat",
+      "ka",
+      NULL,
+      "Keep autorepeat during record/replay",
+      XNEE_GENERAL_OPTION,
+      XNEE_OPTION_VISIBLE
+    },
     {
       XNEE_LAST_OPTION,
       NULL,
@@ -1192,7 +1201,7 @@ xnee_parse_option_impl(xnee_data *xd, char **opt_and_args, int *args_used, int s
 
     case XNEE_EXEC_PROGRAM_KEY:
       verbose_option("XNEE_EXEC_PROGRAM_KEY");
-      xnee_set_exec_prog (xd, opt_and_args[1]);
+      ret = xnee_set_exec_prog (xd, opt_and_args[1]);
       *args_used = 1;
       break;
 
@@ -1247,7 +1256,6 @@ xnee_parse_option_impl(xnee_data *xd, char **opt_and_args, int *args_used, int s
       ret = xnee_unset_sync_mode (xd); 
 /*       ret = xnee_unset_sync_mode_str (xd, opt_and_args[1]); */
 /*       INC_ARGS_USED(*args_used, opt_and_args[1]); */
-      *args_used = 0;
       break;
 
     case XNEE_SYNC_MODE_KEY:
@@ -1255,7 +1263,6 @@ xnee_parse_option_impl(xnee_data *xd, char **opt_and_args, int *args_used, int s
       ret = xnee_set_sync_mode (xd); 
 /*       ret = xnee_set_sync_mode_str (xd, opt_and_args[1]); */
 /*       INC_ARGS_USED(*args_used, opt_and_args[1]); */
-      *args_used = 0;
       break;
 
     case XNEE_RECALL_WINDOW_POS_KEY:
@@ -1270,6 +1277,12 @@ xnee_parse_option_impl(xnee_data *xd, char **opt_and_args, int *args_used, int s
       *args_used = 1;
       break;
 
+    case XNEE_KEEP_AUTOREPEAT:
+      verbose_option("XNEE_KEEP_AUTOREPEAT");
+      ret = xnee_set_keep_autorepeat (xd);
+      *args_used = 0;
+      break;
+
     case XNEE_HUMAN_PRINTOUT_KEY:
       verbose_option("XNEE_HUMAN_PRINTOUT_KEY");
       ret = xnee_set_human_printout(xd);
@@ -1282,7 +1295,6 @@ xnee_parse_option_impl(xnee_data *xd, char **opt_and_args, int *args_used, int s
       *args_used = 1;
       break;
 
-
     case XNEE_FORCE_REPLAY_KEY:
       verbose_option("XNEE_FORCE_REPLAY_KEY");
       ret = xnee_set_force_replay(xd);
@@ -1493,6 +1505,5 @@ xnee_parse_option_impl(xnee_data *xd, char **opt_and_args, int *args_used, int s
       break;
     }
 
-
   return ret;
 }
